@@ -1,32 +1,36 @@
-( cd usr/share/doc/HTML/en_GB/kioslave/telnet ; rm -rf common )
-( cd usr/share/doc/HTML/en_GB/kioslave/telnet ; ln -sf /usr/share/doc/HTML/en_GB//common common )
-( cd usr/share/doc/HTML/en_GB/kioslave/sftp ; rm -rf common )
-( cd usr/share/doc/HTML/en_GB/kioslave/sftp ; ln -sf /usr/share/doc/HTML/en_GB//common common )
-( cd usr/share/doc/HTML/en_GB/kioslave/mailto ; rm -rf common )
-( cd usr/share/doc/HTML/en_GB/kioslave/mailto ; ln -sf /usr/share/doc/HTML/en_GB//common common )
-( cd usr/share/doc/HTML/en_GB/kioslave/nfs ; rm -rf common )
-( cd usr/share/doc/HTML/en_GB/kioslave/nfs ; ln -sf /usr/share/doc/HTML/en_GB//common common )
-( cd usr/share/doc/HTML/en_GB/kioslave/finger ; rm -rf common )
-( cd usr/share/doc/HTML/en_GB/kioslave/finger ; ln -sf /usr/share/doc/HTML/en_GB//common common )
 ( cd usr/share/doc/HTML/en_GB/kioslave/file ; rm -rf common )
 ( cd usr/share/doc/HTML/en_GB/kioslave/file ; ln -sf /usr/share/doc/HTML/en_GB//common common )
-( cd usr/share/doc/HTML/en_GB/kioslave/nntp ; rm -rf common )
-( cd usr/share/doc/HTML/en_GB/kioslave/nntp ; ln -sf /usr/share/doc/HTML/en_GB//common common )
-( cd usr/share/doc/HTML/en_GB/kioslave/floppy ; rm -rf common )
-( cd usr/share/doc/HTML/en_GB/kioslave/floppy ; ln -sf /usr/share/doc/HTML/en_GB//common common )
-( cd usr/share/doc/HTML/en_GB/kioslave/ftp ; rm -rf common )
-( cd usr/share/doc/HTML/en_GB/kioslave/ftp ; ln -sf /usr/share/doc/HTML/en_GB//common common )
-( cd usr/share/doc/HTML/en_GB/kioslave/tar ; rm -rf common )
-( cd usr/share/doc/HTML/en_GB/kioslave/tar ; ln -sf /usr/share/doc/HTML/en_GB//common common )
 ( cd usr/share/doc/HTML/en_GB/kioslave/rlogin ; rm -rf common )
 ( cd usr/share/doc/HTML/en_GB/kioslave/rlogin ; ln -sf /usr/share/doc/HTML/en_GB//common common )
-( cd usr/share/doc/HTML/en_GB/kioslave/ldap ; rm -rf common )
-( cd usr/share/doc/HTML/en_GB/kioslave/ldap ; ln -sf /usr/share/doc/HTML/en_GB//common common )
+( cd usr/share/doc/HTML/en_GB/kioslave/tar ; rm -rf common )
+( cd usr/share/doc/HTML/en_GB/kioslave/tar ; ln -sf /usr/share/doc/HTML/en_GB//common common )
+( cd usr/share/doc/HTML/en_GB/kioslave/finger ; rm -rf common )
+( cd usr/share/doc/HTML/en_GB/kioslave/finger ; ln -sf /usr/share/doc/HTML/en_GB//common common )
+( cd usr/share/doc/HTML/en_GB/kioslave/floppy ; rm -rf common )
+( cd usr/share/doc/HTML/en_GB/kioslave/floppy ; ln -sf /usr/share/doc/HTML/en_GB//common common )
+( cd usr/share/doc/HTML/en_GB/kioslave/mailto ; rm -rf common )
+( cd usr/share/doc/HTML/en_GB/kioslave/mailto ; ln -sf /usr/share/doc/HTML/en_GB//common common )
+( cd usr/share/doc/HTML/en_GB/kioslave/sftp ; rm -rf common )
+( cd usr/share/doc/HTML/en_GB/kioslave/sftp ; ln -sf /usr/share/doc/HTML/en_GB//common common )
+( cd usr/share/doc/HTML/en_GB/kioslave/telnet ; rm -rf common )
+( cd usr/share/doc/HTML/en_GB/kioslave/telnet ; ln -sf /usr/share/doc/HTML/en_GB//common common )
+( cd usr/share/doc/HTML/en_GB/kioslave/news ; rm -rf common )
+( cd usr/share/doc/HTML/en_GB/kioslave/news ; ln -sf /usr/share/doc/HTML/en_GB//common common )
 ( cd usr/share/doc/HTML/en_GB/kioslave/smtp ; rm -rf common )
 ( cd usr/share/doc/HTML/en_GB/kioslave/smtp ; ln -sf /usr/share/doc/HTML/en_GB//common common )
-( cd usr/share/doc/HTML/en_GB/konqueror ; rm -rf common )
-( cd usr/share/doc/HTML/en_GB/konqueror ; ln -sf /usr/share/doc/HTML/en_GB//common common )
+( cd usr/share/doc/HTML/en_GB/kioslave/nfs ; rm -rf common )
+( cd usr/share/doc/HTML/en_GB/kioslave/nfs ; ln -sf /usr/share/doc/HTML/en_GB//common common )
+( cd usr/share/doc/HTML/en_GB/kioslave/ldap ; rm -rf common )
+( cd usr/share/doc/HTML/en_GB/kioslave/ldap ; ln -sf /usr/share/doc/HTML/en_GB//common common )
+( cd usr/share/doc/HTML/en_GB/kioslave/nntp ; rm -rf common )
+( cd usr/share/doc/HTML/en_GB/kioslave/nntp ; ln -sf /usr/share/doc/HTML/en_GB//common common )
+( cd usr/share/doc/HTML/en_GB/kioslave/ftp ; rm -rf common )
+( cd usr/share/doc/HTML/en_GB/kioslave/ftp ; ln -sf /usr/share/doc/HTML/en_GB//common common )
 ( cd usr/share/doc/HTML/en_GB/ksysguard ; rm -rf common )
 ( cd usr/share/doc/HTML/en_GB/ksysguard ; ln -sf /usr/share/doc/HTML/en_GB//common common )
 ( cd usr/share/doc/HTML/en_GB/khelpcenter/glossary ; rm -rf common )
 ( cd usr/share/doc/HTML/en_GB/khelpcenter/glossary ; ln -sf /usr/share/doc/HTML/en_GB//common common )
+( cd usr/share/doc/HTML/en_GB/kalarm ; rm -rf common )
+( cd usr/share/doc/HTML/en_GB/kalarm ; ln -sf /usr/share/doc/HTML/en_GB//common common )
+( cd usr/share/doc/HTML/en_GB/konqueror ; rm -rf common )
+( cd usr/share/doc/HTML/en_GB/konqueror ; ln -sf /usr/share/doc/HTML/en_GB//common common )
